cijoe-pkg-linux: tools for systems development and testing
=========================================================

.. image:: https://img.shields.io/pypi/v/cijoe-pkg-linux.svg
   :target: https://pypi.org/project/cijoe-pkg-linux
   :alt: PyPI

.. image:: https://github.com/refenv/cijoe-pkg-linux/workflows/selftest/badge.svg
   :target: https://github.com/refenv/cijoe-pkg-linux/actions
   :alt: Build Status

This is a utility package for **cijoe**.

Please take a look at the documentation for how to install and use ``cijoe``:

* `Quickstart Guide`_
* `Usage`_

If you find bugs or need help then feel free to submit an `Issue`_. If you want
to get involved head over to the `GitHub page`_ to get the source code and
submit a `Pull request`_ with your changes.

.. _Quickstart Guide: https://cijoe.readthedocs.io/
.. _Usage: https://cijoe.readthedocs.io/
